PrevEntry

Struct PrevEntry 

#[non_exhaustive]
pub struct PrevEntry<T> { pub entry: Result<Entry<T>, Error>, /* private fields */ }
The previous cache entry and metadata.

Passed to the update function to allow more flexible update strategies.

Fields (Non-exhaustive)

This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
entry: Result<Entry<T>, Error>

The actual cache entry, or an error if it failed to deserialize.

Implementations

Source

impl<T> PrevEntry<T>

pub fn is_bad_data(&self) -> bool

Returns true if the cache entry failed to deserialize

pub fn is_checksum_mismatch(&self) -> bool

Returns true if the cache entry has a mismatch with the queried checksum

pub fn is_expired(&self) -> bool

Returns true if cache entry is expired based on the queried TTL