#[non_exhaustive]pub struct PrevEntry<T> {
pub entry: Result<Entry<T>, Error>,
/* private fields */
}Expand description
The previous cache entry and metadata.
Passed to the update function to allow more flexible update strategies.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.entry: Result<Entry<T>, Error>The actual cache entry, or an error if it failed to deserialize.
Implementations
Sourceimpl<T> PrevEntry<T>
impl<T> PrevEntry<T>
Sourcepub fn is_bad_data(&self) -> bool
pub fn is_bad_data(&self) -> bool
Returns true if the cache entry failed to deserialize
Sourcepub fn is_checksum_mismatch(&self) -> bool
pub fn is_checksum_mismatch(&self) -> bool
Returns true if the cache entry has a mismatch with the queried checksum
Sourcepub fn is_expired(&self) -> bool
pub fn is_expired(&self) -> bool
Returns true if cache entry is expired based on the queried TTL